<html>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
    <link rel="stylesheet" href="/static/css/main.css" type="text/css"/>
    <link rel="alternate" href="{{ links.feed }}" type="application/atom+xml" title="Atom feed"/>
    <title>{% block title %}{{ blog.title }}{% endblock title %}</title>
  </head>
  <body>
    <div id="container">
      <div id="header">
        {% block header %}{% endblock header %}
      </div>
      {% block body %}{% endblock body %}
      {% block footer %}
      <div id="footer">
        <p class="rights">{{ license_text }}</p>
        <p class="oak">Blog powered by <a href="http://github.com/marc0s/oak" rel="source">oak</a>.</p>
      </div>
      {% endblock footer %}
    </div>
  </body>
</html>

