{% extends "base.jinja" %}
{% block body %}
<div id="main">
<h2>Posts list</h2>
<ul>
{% for p in posts %}
<li><a href="{{ p.url }}">{{ p.metadata.title }}</a> <span class="date">{{ p.metadata.pub_date|datetimeformat }}</span></li>
{% endfor %}
</ul>
</div>
{% endblock body %}
