/* main.css
 *
 * Based on tomayko.css from tomayko.com
 *
 * CC-BY-SA 2.5
 *
 */


/* 18px base font size / 25px baseline */
body {
	font-size:20px;
	line-height:1.5;   /* 30px */
	margin:0 5px;
	font-family: corbel, 'lucida grande', helvetica, sans-serif;
	color:#212122;
	background-color:#fff;
}

#container {
	max-width:700px;
	margin:0 auto;
}
#container img {
	max-width:700px;
}

h1, h2, h3 {
	font-family:georgia, 'bitstream vera sans serif', 'lucida grande',
		helvetica, verdana, sans-serif;
	font-weight:normal;
	letter-spacing:-0.075em;
	color:#000;
}
i, em {
	font-style:italic;
}
b, strong {
	font-weight:bold;
	color:#222;
}
blockquote {
	color:#555;
}
blockquote em {
	color:#333;
	font-style:italic;
}
blockquote strong {
	color:#333;
	font-weight: normal;
}
dt {
	font-weight:bold;
	color:#000;
}
tt, pre, code, samp, kbd {
	font-family: consolas, 'lucida console', 'bitstream vera sans mono',
		'courier new', monospace;
	color: #000;
}
pre {
	color:#333;
	background-color:#f9f9f9;
}
code {
	color:#007A00;
}
pre code {
	color:#333;
}
a, a:link {
	color:#000;
}
a:visited {
	color:#111;
	background:#fff;
}
a:hover {
	background:#000;
	color:#fff;
	text-decoration:none;
}

/* FORMS */
fieldset {
	border:0;
	padding:0;
}

/* TYPOGRAPHY */

p, ul, ol, dl, pre, blockquote, table, form {
	margin:30px 0;
}
dl {
	margin-left:2em;
}
hr {
	color:#eee;
	background-color:#ccc;
	border:0;
	height:1px;
	margin:45px 0;
}
blockquote {
	font-size:16px;
	line-height:1.88;
	margin:30px 75px 30px 50px;
	padding:0;
}
tt, pre, code, samp, kbd {
	font-size: 16px;
	line-height:1.2;
}
pre {
	margin:20px 0;
	padding:6px 4px 4px 6px;
	border:1px solid #eee;
	border-left-width:20px;
	overflow:auto;
}
h1 {
	font-size:42px;
	line-height:1.43;      /* 50px */
	margin:60px 0;
}
h2 {
	font-size:26px;
	line-height:1.1;         /* 36px */
	margin:25px 0;
}
h3 {
	font-size:26px;
	line-height:1.1;
	margin:25px 0;
}
h4 {
	font-size:20px;
	font-weight:bold;
	line-height:1.5;
	margin:1em 0;
}

/* Tables
--------------------------------------------------------------------------- */

table {
	width:100%;
	border-style:none;
	border-color:#ddd;
	padding:0;
}

th, td {
	padding: 4px 10px 4px 5px;
	border-style:solid;
	border-color:#fff;
}

th {
	font-weight: bold;
	background: #eef;
}

td {
	background: #f9f9f9;
}

tfoot {
	font-style: italic;
}

caption {
	background: #eee;
}

/* Header / Titling
--------------------------------------------------------------------------- */

#header {
	text-align:center;
	margin:50px 0 30px 0;
}
#header h1 {
	margin:-4px 0 0 0;
}
#header h1:first-child {
	margin-top:60px;
}
#header h1 a, #header h1 a:link, #header h1 a:visited, #header h1 a:hover {
	color:#000;
	text-decoration:none;
	background:transparent;
}
#header p {
	margin: 0;
	color: #777;
	font-variant:small-caps;
}
#header p.domain {
	font-size:26px;
	line-height:1;
}
#header p.domain img {
	position:relative;
	top:2px;
}
#header p.thehook, #header p.years {
	font-size:16px;
	letter-spacing:-0.05em;
}
#header p.domain a, #header p.years a {
	text-decoration:none;
}
#header a, #header a:link, #header a:visited {
	color:#717273;
	background:#fff;
}
#header a:hover {
	background:#000;
	color:#fff;
	text-decoration:none;
}
#header .email, #header .site {
	text-transform:none;
	font-variant:normal;
}

/* BOOKMARK CONTENT */
#content.bookmark #body .link a {
	display:block;
	text-decoration:none;
	text-align:center;
}

/* WRITINGS INDEX */
#writings .index .entry {
	float:left;
	width:100%;
	margin:15px 80px 15px 30px;
	clear:left;
}
#writings .index .published {
	width:140px;
	text-align:right;
	letter-spacing:1px;
	color:#818283;
	font-size:20px;
	line-height:1.5;
	margin:0;
}
#writings .index h3 {
	display:block;
	margin:0 100px 0 200px;
	font-size:22px;
	line-height:1.3636;
}

/* APPENDIX */

#appendix {
	margin-top:40px;
	border-top:1px solid #bbb;
}
.tags {
	color:#333;
	margin-top:5px;
	font-variant:small-caps;
	text-transform:lowercase;
	font-weight:bold;
}
.tags a {
	color:#555;
}
.tags a:hover {
	color:#fff;
}


/* FOOTER */

#footer {
	clear:both;
	color:#555;
	font-size:0.88888888em;
	line-height:1.5625;
	border-top:1px solid #ddd;
	padding:19px 0 0 0;
	margin:40px 0 20px 0;
	text-align:center;
}
#footer p {
	margin:0;
}
#footer form {
	float:right;
}
#footer input{
	font-size:10px;
}

/* MISC HELPER STYLES */

p small, p.note, .intro {
	font-size:0.8333333em; /* 15px */
	line-height:1.85;
	color:#555;
	margin:1.45em 0;
}
ul.clean, ol.clean {
	list-style-type: none;
	padding-left: 0;
}
.caps {
	font-variant:small-caps;
}
.clear {
	clear:both;
}
.left{
	float:left;
}
.right{
	float:right;
}
.intro {
	border:1px solid #ccc;
	padding:0.5em;
	font-style:italic;
}

/* INDEX */
.index .entry {
	margin:50px 80px 50px 100px;
}
.index .summary {
	margin-bottom:30px;
	color:#414243;
}
.index h3 {
	font-size:22px;
	line-height:1.36;
	font-weight:normal;
	display:inline;
}
.index h3 strong {
	font-size:22px;
	line-height:1.36;
	color:#515253;
	padding:0 7px;
}
.index h3 a {
	color:#000;
	background:#fff;
}
.index h3 + p{
	display:inline;
	margin-left:0px;
}
.index p.meta {
	font-size:18px;
	line-height:1.67;
	color:#616163;
	margin:-28px 0 0 0;
}
.index p.meta .time {
	color:#616163;
}
.index img.icon {
	position:relative;
	top:3px;
	border:0;
}
.index .published {
	width:75px;
	text-align:center;
	float:left;
	text-transform:capitalize;
	font-variant:small-caps;
	color:#616263;
	font-size:14px;
	margin-top:0;
}
.index .published .day {
	display:block;
	color:#414243;
	font-size:30px;
	font-family:georgia;
	line-height:1.1;
	margin-bottom:5px;
}
#container .index img {
	max-width:520px;
}
/* PRINT */

@media print {
	html, body, #container {
		margin:0;
	}
	#container {
		width:100%;
		max-width:100%;
	}
	#header {
		margin-top:0;
	}
	#footer {
		display:none;
	}
	a, a:link, a:visited {
		color:#000;
		background:#fff;
		text-decoration:none;
	}
	@page {
		size:8.5in 11in;
	}
}


/* RESUME */

.chrono h3 {
	margin-bottom:0;
}
.chrono p.period {
	text-align:right;
	font-weight:bold;
}
.chrono p.biz {
	float:left;
}
.chrono .stuff {
	clear:all;
}
.chrono li li {
	list-style-type:disc;
}
@media print {
	.chrono p.biz a {
		font-weight:bold;
	}
}

/* ABOUT */

.about img.me {
	float:left;
	border:1px solid #333;
	margin:5px 25px 25px 0;
}

/* PRETTIFICATION OF SOURCE CODE */

.str { color: #181; font-style:italic; }
.kwd { color: #369; }
.com { color: #666; }
.typ { color: #c40; }
.lit { color: #900; }
.pun { color: #000; font-weight: bold; }
.pln { color: #333; }
.tag { color: #369; font-weight: bold; }
.atn { color: #939; font-weight: bold }
.atv { color: #181; }
.dec { color: #606; }

@media print {
	.str { color: #060; }
	.kwd { color: #006; font-weight: bold; }
	.com { color: #600; font-style: italic; }
	.typ { color: #404; font-weight: bold; }
	.lit { color: #044; }
	.pun { color: #440; }
	.pln { color: #000; }
	.tag { color: #006; font-weight: bold; }
	.atn { color: #404; }
	.atv { color: #060; }
}

