{% extends "base.jinja" %}
{% block body %}
<div id="main">
    <h2>Tag list</h2>
    <ul>
    {% for k,v in tags.iteritems() %}
        <li><a href="{{v.url}}">{{v.tag}}</a> ({{v.posts|length}})</li>
    {% endfor %}
    </ul>
</div>
{% endblock body %}
