{% extends "base.jinja" %}
{% block title %}
{{ post.metadata.title }}
{% endblock title %}
{% block header %}
<p><a href="{{ links.site }}" rel="home">{{ blog.title }}</a></p>
<h1 id="title">{{ post.metadata.title }}</h1>
<p class="date">{{ post.metadata.pub_date|longdate }}</p>
{% endblock header %}

{% block body %}
<div id="content" class="entry">
  <div id="body">
    {{ post.html }}
  </div>
  <div id="appendix">
    <p class="tags">Tagged as {{ post.metadata.tags|join(', ') or '... No tags found!' }}</p>
  </div>
</div>
{% endblock body %}
  
